@@ -1,12 +1,16 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2008 Emweb bvba, Kessel-Lo, Belgium.
+ * Copyright (C) 2008 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
 #ifndef DOMELEMENT_H_
 #define DOMELEMENT_H_
 
+#if defined(WT_THREADED) || defined(WT_TARGET_JAVA)
+#include <atomic>
+#endif
+
 #include <map>
 #include <vector>
 #include <string>
@@ -316,6 +320,11 @@ public:
    */
   void setTimeout(int msec, bool jsRepeat);
 
+  /*! \brief Configures the DOM element as a source for timed events,
+   *         with given initial delay and interval, always repeating.
+   */
+  void setTimeout(int delay, int interval);
+
   /*! \brief Calls a JavaScript method on the DOM element.
    */
   void callMethod(const std::string& method);
@@ -374,10 +383,10 @@ public:
   struct TimeoutEvent {
     int msec;
     std::string event;
-    bool repeat;
+    int repeat;
 
     TimeoutEvent() { }
-    TimeoutEvent(int m, const std::string& e, bool r)
+    TimeoutEvent(int m, const std::string& e, int r)
       : msec(m), event(e), repeat(r) { }
   };
 
@@ -558,7 +567,7 @@ private:
   std::string  id_;
   int          numManipulations_;
   int          timeOut_;
-  bool         timeOutJSRepeat_;
+  int          timeOutJSRepeat_;
   EStream      javaScript_;
   std::string  javaScriptEvenWhenDeleted_;
   mutable std::string var_;
@@ -585,7 +594,11 @@ private:
   TimeoutList timeouts_;
   std::string elementTagName_;
 
-  static int nextId_;
+#if defined(WT_THREADED) || defined(WT_TARGET_JAVA)
+  static std::atomic<unsigned> nextId_;
+#else
+  static unsigned nextId_;
+#endif
 
   friend class WCssDecorationStyle;
 };
